@@ -17,9 +17,9 @@
 
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
-__version__ = '0.4'
-__author__ = "Carlos Silva"
-__email__ = "carlosqsilva@outlook.com"
+__version__ = '1.0.7'
+__author__ = "Brendan Perry"
+__email__ = "bperry@hey.com"
 
 import warnings
 warnings.simplefilter("ignore")
